package fer.hr.help;

import fer.hr.preprocessing.binarisation.IBinarisation;
import fer.hr.preprocessing.binarisation.OtsuBinarisation;
import fer.hr.preprocessing.greyscale.Greyscale;
import fer.hr.preprocessing.greyscale.IGreyscaleConvert;
import fer.hr.preprocessing.histogram.ColumnSumHistogram;
import fer.hr.preprocessing.histogram.IHistogram;
import fer.hr.preprocessing.histogram.PixelHistogram;
import fer.hr.preprocessing.histogram.RowSumHistogram;
import fer.hr.segmentation.ISegmentation;
import fer.hr.segmentation.SegmentationWithPresetThreshold;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * Created by jcular on 4/3/16.
 */
public class PictureSpliting {
    private static String picturePath = "../seven-segment";
    public static void main(String[] args) {
        IHistogram columnSum = new ColumnSumHistogram();
        IHistogram rowSum = new RowSumHistogram();
        ISegmentation segmentation = new SegmentationWithPresetThreshold(rowSum, columnSum);
        IHistogram pixelHistogram = new PixelHistogram();
        IBinarisation otsuBinarisation = new OtsuBinarisation();
        IGreyscaleConvert greyscaleConvert = new Greyscale();
        File dir = new File(picturePath);
        File[] directoryListing = dir.listFiles();
        try {
            if (directoryListing != null) {
                for (File child : directoryListing) {
                    BufferedImage bufferedImage = ImageIO.read(new File(String.valueOf(child)));
                    bufferedImage = greyscaleConvert.convertToGrey(bufferedImage);
                    double[] hist = pixelHistogram.calculateHistogram(bufferedImage);
                    BufferedImage img = otsuBinarisation.convertImage(bufferedImage, hist);
                    splitImagesAndSave(segmentation, child, img, 0);
//
//                    File newDir = new File(picturePath+"-split");
//                    newDir.mkdirs();
//
//                    File f = new File(String.valueOf(newDir)+"/" + child.getName() + "kek");
//                    ImageIO.write(bufferedImage, "PNG", f);
//
//
//                    f = new File(String.valueOf(newDir)+"/" + child.getName());
//                    ImageIO.write(img, "PNG", f);
                    }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

    }

    private static void splitImagesAndSave(ISegmentation segmentation, File child, BufferedImage img, int filename) throws IOException {
        List<BufferedImage> extracted = segmentation.extractCharacters(img);
        if (extracted.size() != 10) {
            System.out.println(String.valueOf(child));
        }
        String folderName = String.valueOf(child).replace(".png", "").replace(picturePath, "");

        for(BufferedImage character: extracted) {
            File newDir = new File(picturePath + "-split/" + folderName);
            newDir.mkdirs();
            File f = new File(String.valueOf(newDir)+"/"+ filename++ );
            ImageIO.write(character, "JPEG", f);
        }
    }
}
