package fer.hr.preprocessing.histogram;

import java.awt.image.BufferedImage;

/**
 * Created by jcular on 5/12/16.
 */
public abstract class AbstractBreakPointFinder {
    public enum Direction{
        TOP, BOT, LEFT, RIGHT
    }
    public double[] findBreakPointInImage(BufferedImage image, Direction direction) {
        if (direction == Direction.TOP) {
            return findTop(image);
        } else if (direction == Direction.BOT) {
            return findBot(image);
        } else if (direction == Direction.LEFT) {
            return findLeft(image);
        } else {
            return findRight(image);
        }
    }

    private double[] findBot(BufferedImage image) {
        double[] projection = new double[image.getWidth()];
        for (int i = 0; i < image.getWidth(); i++) {
            for (int j = image.getHeight()-1; j >= 0; j--) {
                if (j == 0 || (image.getRGB(i, j) & 0xFF) == 0) {
                    projection[i] = image.getHeight() - j;
                    break;
                }
            }
        }
        return projection;
    }

    private double[] findTop(BufferedImage image) {
        double[] projection = new double[image.getWidth()];
        for (int i = 0; i < image.getWidth(); i++) {
            for (int j = 0; j < image.getHeight() ; j++) {
                if (j == image.getHeight()-1 || (image.getRGB(i, j) & 0xFF) == 0) {
                    projection[i] = j;
                    break;
                }
            }
        }
        return projection;
    }

    private double[] findLeft(BufferedImage image) {
        double[] projection = new double[image.getHeight()];
        for (int j = 0; j < image.getHeight(); j++) {
            for (int i = 0; i < image.getWidth(); i++) {
                if (i == image.getWidth() - 1 || (image.getRGB(i, j) & 0xFF) == 0) {
                    projection[j] = i;
                    break;
                }
            }
        }
        return projection;
    }

    private double[] findRight(BufferedImage image) {
        double[] projection = new double[image.getHeight()];
        for (int j = 0; j < image.getHeight(); j++) {
            for (int i = image.getWidth()-1; i >= 0 ; i--) {
                if (i == 0 || (image.getRGB(i, j) & 0xFF) == 0) {
                    projection[j] = image.getWidth() - i;
                    break;
                }
            }
        }
        return projection;
    }
}
